pub struct JupiterBuilder { /* private fields */ }Expand description
Jupiter V6 aggregator swap builder Uses Jupiter’s REST API to get the optimal route and swap transaction
Implementations
Sourceimpl JupiterBuilder
impl JupiterBuilder
pub fn new() -> Self
Sourcepub async fn get_quote(
&self,
input_mint: &Pubkey,
output_mint: &Pubkey,
amount: u64,
slippage_bps: u16,
) -> Result<Value>
pub async fn get_quote( &self, input_mint: &Pubkey, output_mint: &Pubkey, amount: u64, slippage_bps: u16, ) -> Result<Value>
Get a swap quote from Jupiter API
Sourcepub async fn get_swap_transaction(
&self,
quote: &Value,
user_public_key: &Pubkey,
) -> Result<Vec<u8>>
pub async fn get_swap_transaction( &self, quote: &Value, user_public_key: &Pubkey, ) -> Result<Vec<u8>>
Get a swap transaction from Jupiter API
Sourcepub fn deserialize_transaction(
&self,
tx_bytes: &[u8],
) -> Result<VersionedTransaction>
pub fn deserialize_transaction( &self, tx_bytes: &[u8], ) -> Result<VersionedTransaction>
Deserialize a bincode-encoded VersionedTransaction from raw bytes.
Returns Err on empty input, malformed bytes, or any bincode decode failure (Req 8.3).